import { Switch, Route } from "wouter";
import { Toaster } from "@/components/ui/toaster";
import { QueryClientProvider } from "@tanstack/react-query";
import { queryClient } from "@/lib/queryClient";

// Components
import Navbar from "@/components/Navbar";
import Footer from "@/components/Footer";

// Pages
import Home from "@/pages/Home";
import Features from "@/pages/Features";
import Benefits from "@/pages/Benefits";
import Pricing from "@/pages/Pricing";
import Blog from "@/pages/Blog";
import BlogPost from "@/pages/BlogPost";
import Documentation from "@/pages/Documentation";
import HelpDesk from "@/pages/HelpDesk";
import About from "@/pages/About";
import Contact from "@/pages/Contact";
import Beta from "@/pages/Beta";
import BetaFeedback from "@/pages/BetaFeedback";
import Launch from "@/pages/Launch";
import NotFound from "@/pages/not-found";
import AdminDashboard from "@/pages/AdminDashboard";
import BlogAutomation from "@/pages/BlogAutomation";
import ContentWorkflow from "@/pages/ContentWorkflow";
import AuthPage from "@/pages/auth-page";

// Admin Pages
import AdminAnalytics from "@/pages/admin/Analytics";
import AdminContent from "@/pages/admin/Content";
import AdminBots from "@/pages/admin/Bots";
import AdminLaunch from "@/pages/admin/Launch";
import AdminBeta from "@/pages/admin/Beta";
import AdminFeedback from "@/pages/admin/Feedback";
import AdminContacts from "@/pages/admin/Contacts";
import AdminSlack from "@/pages/admin/Slack";
import AdminConfig from "@/pages/admin/Config";
import RealTimeAnalytics from "@/pages/admin/RealTimeAnalytics";

// Auth
import { AuthProvider } from "@/hooks/use-auth";
import { ProtectedRoute } from "@/lib/protected-route";
import { useScrollToTop } from "@/hooks/use-scroll-to-top";

function Router() {
  // Use the scroll to top hook for automatic scrolling on route change
  useScrollToTop();
  
  return (
    <Switch>
      {/* Public Routes */}
      <Route path="/" component={Home} />
      <Route path="/features" component={Features} />
      <Route path="/benefits" component={Benefits} />
      <Route path="/pricing" component={Pricing} />
      <Route path="/blog" component={Blog} />
      <Route path="/blog/:slug" component={BlogPost} />
      <Route path="/docs" component={Documentation} />
      <Route path="/helpdesk" component={HelpDesk} />
      <Route path="/about" component={About} />
      <Route path="/contact" component={Contact} />
      <Route path="/beta" component={Beta} />
      <Route path="/beta-feedback" component={BetaFeedback} />
      <Route path="/launch" component={Launch} />
      <Route path="/auth" component={AuthPage} />
      
      {/* Protected Routes */}
      <ProtectedRoute path="/admin" component={AdminDashboard} />
      <ProtectedRoute path="/admin/analytics" component={AdminAnalytics} />
      <ProtectedRoute path="/admin/real-time-analytics" component={RealTimeAnalytics} />
      <ProtectedRoute path="/admin/content" component={AdminContent} />
      <ProtectedRoute path="/admin/bots" component={AdminBots} />
      <ProtectedRoute path="/admin/launch" component={AdminLaunch} />
      <ProtectedRoute path="/admin/beta" component={AdminBeta} />
      <ProtectedRoute path="/admin/feedback" component={AdminFeedback} />
      <ProtectedRoute path="/admin/contacts" component={AdminContacts} />
      <ProtectedRoute path="/admin/slack" component={AdminSlack} />
      <ProtectedRoute path="/admin/config" component={AdminConfig} />
      <ProtectedRoute path="/admin/blog-automation" component={BlogAutomation} />
      <ProtectedRoute path="/admin/content-workflow" component={ContentWorkflow} />
      
      {/* 404 Route */}
      <Route component={NotFound} />
    </Switch>
  );
}

function App() {
  return (
    <QueryClientProvider client={queryClient}>
      <AuthProvider>
        <div className="flex flex-col min-h-screen">
          <Navbar />
          <main className="flex-grow">
            <Router />
          </main>
          <Footer />
          <Toaster />
        </div>
      </AuthProvider>
    </QueryClientProvider>
  );
}

export default App;
